Index: flashchips.c
===================================================================
--- flashchips.c
+++ flashchips.c
@@ -9151,6 +9151,37 @@ const struct flashchip flashchips[] = {
 		.voltage	= {3000, 3600},
 	},
 
+    {
+        .vendor     = "Sanyo",
+        .name       = "LE25FW106",
+        .bustype    = BUS_SPI,
+        .manufacture_id	= SANYO_ID,
+        .model_id   = SANYO_LE25FW106,
+        .total_size = 128,
+        .page_size  = 256,
+        .feature_bits   = FEATURE_WRSR_WREN,
+        .tested     = TEST_OK_PREW,
+        .probe      = probe_spi_res2,
+        .probe_timing   = TIMING_ZERO,
+        .block_erasers  = {
+            {
+                .eraseblocks = { {2 * 1024, 64} },
+                .block_erase = spi_block_erase_d7,
+            }, {
+                .eraseblocks = { {32 * 1024, 4} },
+                .block_erase = spi_block_erase_d8,
+            }, {
+                .eraseblocks = { {128 * 1024, 1} },
+                .block_erase = spi_block_erase_c7,
+                }
+            },
+        .printlock  = spi_prettyprint_status_register_plain,
+        .unlock     = spi_disable_blockprotect,
+        .write      = spi_chip_write_256,
+        .read       = spi_chip_read,
+        .voltage    = {2700, 3600},
+    },
+
 	{
 		.vendor		= "Sanyo",
 		.name		= "LE25FW406A",
Index: flashchips.h
===================================================================
--- flashchips.h
+++ flashchips.h
@@ -537,6 +537,7 @@
 #define SANYO_ID		0x62    /* Sanyo */
 #define SANYO_LE25FW203A	0x1600
 #define SANYO_LE25FW403A	0x1100
+#define SANYO_LE25FW106     0x15
 #define SANYO_LE25FW406		0x07	/* RES2 */
 #define SANYO_LE25FW418A	0x10	/* RES2 and some weird 1 byte RDID variant */
 #define SANYO_LE25FW406A	0x1A	/* RES2, no datasheet */
